"""
Author: Anoop Ajaya Kumar Nair
Date: 2023-10-24
Description: Code calculates:
    - Density cube
    - Quadrupole

Contact Details:
- Email: mailanoopanair@gmail.com
- Company: University of Iceland
- Job Title: Doctoral researcher
"""

import numpy
from pyscf import lib
from pyscf.dft import numint, gen_grid
from pyscf import __config__

RESOLUTION = getattr(__config__, 'cubegen_resolution', None)
BOX_MARGIN = getattr(__config__, 'cubegen_box_margin', 10.0)
ORIGIN = getattr(__config__, 'cubegen_box_origin', None)
EXTENT = getattr(__config__, 'cubegen_box_extent', None)
import numpy as np


class Cube(object):
    def __init__(self, mol, nx=80, ny=80, nz=80, resolution=RESOLUTION,
                 margin=BOX_MARGIN, origin=ORIGIN, extent=EXTENT):
        from pyscf.pbc.gto import Cell
        self.mol = mol
        coord = mol.atom_coords()
        # print(coord)

        if isinstance(mol, Cell):
            self.box = mol.lattice_vectors()
            atom_center = (numpy.max(coord, axis=0) + numpy.min(coord, axis=0))/2
            box_center = (self.box[0] + self.box[1] + self.box[2])/2
            self.boxorig = atom_center - box_center
        else:
            
            if extent is None:
                extent = numpy.max(coord, axis=0) - numpy.min(coord, axis=0) + 2*margin
                extent.fill(np.max(extent))

            self.box = numpy.diag(extent)
            if origin is None:
                origin = np.zeros(3)
                origin.fill(numpy.min(coord) - margin)
            self.boxorig = numpy.asarray(origin)

        if resolution is not None:
            nx, ny, nz = numpy.ceil(numpy.diag(self.box) / resolution).astype(int)

        self.nx = nx
        self.ny = ny
        self.nz = nz

        if isinstance(mol, Cell):
            # Use an asymmetric mesh for tiling unit cells
            self.xs = numpy.linspace(0, 1, nx, endpoint=False)
            self.ys = numpy.linspace(0, 1, ny, endpoint=False)
            self.zs = numpy.linspace(0, 1, nz, endpoint=False)
        else:
            self.xs = numpy.linspace(0, 1, nx, endpoint=True)
            self.ys = numpy.linspace(0, 1, ny, endpoint=True)
            self.zs = numpy.linspace(0, 1, nz, endpoint=True)


    def get_coords(self) :
        """  Result: set of coordinates to compute a field which is to be stored
        in the file.
        """
        frac_coords = lib.cartesian_prod([self.xs, self.ys, self.zs])
        return frac_coords @ self.box + self.boxorig # Convert fractional coordinates to real-space coordinates

    def get_ngrids(self):
        return self.nx * self.ny * self.nz

    def get_volume_element(self):
        return (self.xs[1]-self.xs[0])*(self.ys[1]-self.ys[0])*(self.zs[1]-self.zs[0])






def density(mol, dm, outfile=None, nx=80, ny=80, nz=80,  resolution=RESOLUTION,
            margin=BOX_MARGIN):

    from pyscf.pbc.gto import Cell
    cc = Cube(mol, nx, ny, nz, resolution, margin)

    GTOval = 'GTOval'
    if isinstance(mol, Cell):
        GTOval = 'PBC' + GTOval

    # Compute density on the .cube grid
    coords = cc.get_coords()
    ngrids = cc.get_ngrids()
    coordMod = coords.reshape(nx, ny, nz,3)

    h_v = np.zeros(3)
    hv1 = coordMod[0,0,0]-coordMod[1,0,0]
    hv2 = coordMod[0,0,0]-coordMod[0,1,0]
    hv3 = coordMod[0,0,0]-coordMod[0,0,1]
    h_v[0] = abs(hv1[0])
    h_v[1] = abs(hv2[1])
    h_v[2] = abs(hv3[2])



    blksize = min(8000, ngrids)
    rho = numpy.empty(ngrids)
    for ip0, ip1 in lib.prange(0, ngrids, blksize):
        ao = mol.eval_gto(GTOval, coords[ip0:ip1])
        rho[ip0:ip1] = numint.eval_rho(mol, ao, dm)
    rho = rho.reshape(cc.nx,cc.ny,cc.nz)

    # Write out density to the .cube file
    if outfile !=None:
        cc.write(rho, outfile, comment='Electron density in real space (e/Bohr^3)')
    return rho,[nx,ny,nz],h_v,coordMod

def quadpoleElect(h_v,R_v,rho,n,coordMod):

    dV = h_v[0] * h_v[1] * h_v[2] #done

    Q_ab = np.zeros(6)
    for i in range(0,n[0]):
        x = i * h_v[0]
        for j in range(0,n[1]):
            y = j* h_v[1]
            for k in range(0,n[2]):
                z = k * h_v[2]
                r = np.zeros(3)
                r[0] = coordMod[i,j,k,0] - R_v[0]
                r[1] = coordMod[i,j,k,1] - R_v[1] 
                r[2] = coordMod[i,j,k,2] - R_v[2] 
                rr = (r[0] * r[0] + r[1] * r[1] + r[2] * r[2])
                rq = rr / 3.0
                cd = rho[i,j,k] * dV

                cq = cd * 3.0 / 2.0
                Q_ab[0] += cq * (r[0] * r[0] - rq)
                Q_ab[1] += cq * r[0] * r[1]
                Q_ab[2] += cq * r[0] * r[2]
                Q_ab[3] += cq * (r[1] * r[1] - rq)
                Q_ab[4] += cq * r[1] * r[2]
                Q_ab[5] += cq * (r[2] * r[2] - rq)
    quadPole = np.zeros((3,3))
    quadPole[0,0] = Q_ab[0] 
    quadPole[0,1] = quadPole[1,0] =  Q_ab[1] 
    quadPole[0,2] = quadPole[2,0] =  Q_ab[2] 
    quadPole[1,1] = Q_ab[3] 
    quadPole[1,2] = quadPole[2,1] =  Q_ab[4] 
    quadPole[2,2] = Q_ab[5] 
    return quadPole


def calcCOM(mol):
    atomicMass  = mol.atom_mass_list()
    atomicPos   = mol.atom_coords(unit = 'Bohr')
    Com = np.matmul(atomicMass.reshape(1,-1),atomicPos.reshape(-1,3))/atomicMass.sum()
    return Com[0]

def quadpoleNuc(mol):
    charges = mol.atom_charges()
    coords = mol.atom_coords(unit = 'Bohr')
    COM = calcCOM(mol)
    coordsMod = coords-COM
    # print("qcoord",coordsMod)

    rval = np.sum(np.square(coordsMod),axis=1)
    Quad  = np.zeros((3,3))
    for i in range(len(charges)):
        rvalDiag = np.zeros((3,3))
        rvalDiag[0,0] =  -rval[i]/2.0
        rvalDiag[1,1] =  -rval[i]/2.0
        rvalDiag[2,2] =  -rval[i]/2.0
        Quad += charges[i]*(3.0/2.0*np.outer(coordsMod[i],coordsMod[i])+rvalDiag)

 
    return Quad

def Quadrupole(mol,mf):
    quad_Nuc1 = quadpoleNuc(mol)
    R_v = calcCOM(mol)
    rho,n,h_v,coordMod = density(mol, mf.make_rdm1())
    Qelect1 = quadpoleElect(h_v,R_v,rho,n,coordMod)
    Qxx = np.round(quad_Nuc1-Qelect1,4)
    return Qxx








"""
Author: Anoop Ajaya Kumar Nair
Date: 2023-10-24
Description: Code calculates:
    - Dipole Quadrupole polarizability tensor
    - Quadrupole Quadrupole polarizability tensor

Contact Details:
- Email: mailanoopanair@gmail.com
- Company: University of Iceland
- Job Title: Doctoral researcher
"""

from pyscf import qmmm, scf
from qdist import Vi, Vij
from ase.units import Bohr, Ha
import numpy as np
from momtensor import Quadrupole



def calc_Pertb_DP(mol_system, 
                  mol_COM, 
                  mol_xc_func, 
                  box_dim, 
                  field_component, 
                  field_strength):

    charge_postions, charge_mag = Vij(mol_COM,
                                      box_dim, 
                                      field_strength,
                                      field_component)
    
    mf = qmmm.mm_charge(scf.RKS(mol_system), 
                        charge_postions, 
                        charge_mag,
                        unit='AU')
    mf.xc = mol_xc_func
    mf.kernel()
    dp_mom = mf.dip_moment()
    return dp_mom


def calc_Pertb_QP(mol_system, 
                  mol_COM, 
                  mol_xc_func, 
                  box_dim, 
                  field_component, 
                  field_strength):

    charge_postions, charge_mag =Vi(mol_COM,
                                    box_dim, 
                                    field_strength,
                                    field_component)
    
    mf = qmmm.mm_charge(scf.RKS(mol_system), 
                        charge_postions, 
                        charge_mag,
                        unit='AU')
    mf.xc = mol_xc_func
    mf.kernel()
    qp_mom = Quadrupole(mol_system,mf)
    return qp_mom





def calc_FFPertb_Qpole(mol_system, 
                       mol_COM, 
                       mol_xc_func, 
                       box_dim, 
                       field_component, 
                       field_strength):
    charge_postions, charge_mag = Vij(mol_COM,
                                        box_dim, 
                                        field_strength,
                                        field_component)
    mf = qmmm.mm_charge(scf.RKS(mol_system), 
                        charge_postions, 
                        charge_mag,
                        unit='AU')
    mf.xc = mol_xc_func
    mf.kernel()
    qp_mom = Quadrupole(mol_system,mf)
    return qp_mom






class Pols:

    def __init__(   self,
                    mol_struct,
                    mol_system, 
                    mol_xc_func = "pbe",
                    box_dim = 14,
                    field_strength_F = 0.486/Ha*Bohr,
                    field_strength_FF = 0.0486/Ha*Bohr*Bohr,
                    irrep=False):

        self.mol_struct          =  mol_struct
        self.mol_system          = mol_system
        self.box_dim             = box_dim
        self.mol_COM             = self.mol_struct.get_center_of_mass()
        self.field_strength_FF   = field_strength_FF
        self.mol_xc_func         = mol_xc_func
        self.CONST_DPtoAU        = 0.393456/(self.field_strength_FF)
        self.field_strength_F    = field_strength_F
        self.field_strength_ref  = 0.0
        self.field_x             = 'x'
        self.field_y             = 'y'
        self.field_z             = 'z'
        self.field_xx            = "xx"
        self.field_xy            = "xy"
        self.field_xz            = "xz"
        self.field_yy            = 'yy'
        self.field_yz            = 'yz'
        self.field_zz            = 'zz'
        self.irrep               = irrep


    def calcAijk(self):
        print("calc AIJK")
        # Ai,xx 
        self.DP_XX  = calc_Pertb_DP(self.mol_system, 
                                self.mol_COM, 
                                self.mol_xc_func, 
                                self.box_dim, 
                                self.field_xx, 
                                self.field_strength_FF)

        # Ai,yy
        self.DP_YY = calc_Pertb_DP(self.mol_system, 
                                self.mol_COM, 
                                self.mol_xc_func, 
                                self.box_dim, 
                                self.field_yy, 
                                self.field_strength_FF)

        # Ai,zz
        self.DP_ZZ = calc_Pertb_DP(self.mol_system, 
                                self.mol_COM, 
                                self.mol_xc_func, 
                                self.box_dim, 
                                self.field_zz, 
                                self.field_strength_FF)

        # Q0
        self.QP_REF = calc_Pertb_QP(self.mol_system, 
                            self.mol_COM, 
                            self.mol_xc_func, 
                            self.box_dim, 
                            self.field_x, 
                            self.field_strength_ref)


        # Aij,x
        self.QP_X = calc_Pertb_QP(self.mol_system, 
                            self.mol_COM, 
                            self.mol_xc_func, 
                            self.box_dim, 
                            self.field_x, 
                            self.field_strength_F)
        

        # Aij,y
        self.QP_Y = calc_Pertb_QP(self.mol_system, 
                            self.mol_COM, 
                            self.mol_xc_func, 
                            self.box_dim, 
                            self.field_y, 
                            self.field_strength_F)

        # Aij,z
        self.QP_Z = calc_Pertb_QP(self.mol_system, 
                            self.mol_COM, 
                            self.mol_xc_func, 
                            self.box_dim, 
                            self.field_z, 
                            self.field_strength_F)

        AiXX = (self.DP_XX-self.DP_YY)*self.CONST_DPtoAU
        AiYY = (self.DP_YY-self.DP_ZZ)*self.CONST_DPtoAU
        AiZZ = (self.DP_ZZ-self.DP_XX)*self.CONST_DPtoAU
        AijX = (self.QP_X-self.QP_REF)/(self.field_strength_F)
        AijY = (self.QP_Y-self.QP_REF)/(self.field_strength_F)
        AijZ = (self.QP_Z-self.QP_REF)/(self.field_strength_F)


        # Irreducible representation


        self.DQ_IJK_IRREP = np.zeros((18))
        self.DQ_IJK_IRREP[[0,6,12]]     = AiXX
        self.DQ_IJK_IRREP[[3,9,15]]     = AiYY
        self.DQ_IJK_IRREP[[5,11,17]]    = AiZZ
        self.DQ_IJK_IRREP[[1,2,4]] = AijX[[0,0,1],[1,2,2]]
        self.DQ_IJK_IRREP[[7,8,10]] = AijY[[0,0,1],[1,2,2]]
        self.DQ_IJK_IRREP[[13,14,16]] = AijZ[[0,0,1],[1,2,2]]



        # Full matrix representation
        self.DQ_IJK = np.zeros((3,3,3))
        self.DQ_IJK[:,0,0] = AiXX
        self.DQ_IJK[:,1,1] = AiYY
        self.DQ_IJK[:,2,2] = AiZZ
        self.DQ_IJK[0,[0,0,1],[1,2,2]] = AijX[[0,0,1],[1,2,2]]
        self.DQ_IJK[1,[0,0,1],[1,2,2]] = AijY[[0,0,1],[1,2,2]]
        self.DQ_IJK[2,[0,0,1],[1,2,2]] = AijZ[[0,0,1],[1,2,2]]
        self.DQ_IJK[0,[1,2,2],[0,0,1]] = AijX[[0,0,1],[1,2,2]]
        self.DQ_IJK[1,[1,2,2],[0,0,1]] = AijY[[0,0,1],[1,2,2]]
        self.DQ_IJK[2,[1,2,2],[0,0,1]] = AijZ[[0,0,1],[1,2,2]]

        if self.irrep == True:
            np.save("H2O_mono_AIJK_Trrep.npy",np.round(-self.DQ_IJK_IRREP,4))
            return np.round(self.DQ_IJK_IRREP,4)
        else:
            np.save("H2O_mono_AIJK.npy",np.round(-self.DQ_IJK,4))
            return np.round(self.DQ_IJK,4)





    def calcCijkl(self):

        self.QQ_IJKL = np.zeros((3,3,3,3))

        # QP_REF
        self.QP_REF = calc_FFPertb_Qpole(self.mol_system, 
                                         self.mol_COM, 
                                         self.mol_xc_func, 
                                         self.box_dim, 
                                         self.field_xx, 
                                         self.field_strength_ref)

        # Cij,xx
        self.QP_XX = calc_FFPertb_Qpole(self.mol_system, 
                                 self.mol_COM, 
                                 self.mol_xc_func, 
                                 self.box_dim, 
                                 self.field_xx, 
                                 self.field_strength_FF)

        # Cij,yy
        self.QP_YY = calc_FFPertb_Qpole(self.mol_system, 
                                 self.mol_COM, 
                                 self.mol_xc_func, 
                                 self.box_dim, 
                                 self.field_yy, 
                                 self.field_strength_FF)

        # Cij,zz
        self.QP_ZZ = calc_FFPertb_Qpole(self.mol_system, 
                                 self.mol_COM, 
                                 self.mol_xc_func, 
                                 self.box_dim, 
                                 self.field_zz, 
                                 self.field_strength_FF)

        # Cij,xy
        self.QP_XY = calc_FFPertb_Qpole(self.mol_system, 
                                 self.mol_COM, 
                                 self.mol_xc_func, 
                                 self.box_dim, 
                                 self.field_xy, 
                                 self.field_strength_FF)

        # Cij,xz
        self.QP_XZ = calc_FFPertb_Qpole(self.mol_system, 
                                 self.mol_COM, 
                                 self.mol_xc_func, 
                                 self.box_dim, 
                                 self.field_xz, 
                                 self.field_strength_FF)

        # Cij,yz
        self.QP_YZ = calc_FFPertb_Qpole(self.mol_system, 
                                 self.mol_COM, 
                                 self.mol_xc_func, 
                                 self.box_dim, 
                                 self.field_yz, 
                                 self.field_strength_FF)

        Cijxx = (self.QP_XX - self.QP_YY)/(3*self.field_strength_FF)
        Cijyy = (self.QP_YY - self.QP_ZZ)/(3*self.field_strength_FF)
        Cijzz = (self.QP_ZZ - self.QP_XX)/(3*self.field_strength_FF)
        Cijxy = (self.QP_XY - self.QP_REF)/self.field_strength_FF
        Cijyz = (self.QP_YZ - self.QP_REF)/self.field_strength_FF
        Cijxz = (self.QP_XZ - self.QP_REF)/self.field_strength_FF
        Cxyxy = Cijxy[0,1]/2.0
        Cxyyz = Cijyz[0,1]
        Cxzyz = Cijyz[0,2]
        Cyzyz = Cijyz[1,2]/2.0
        Cxyxz = Cijxz[0,1]
        Cxzxz = Cijxz[0,2]/2.0
        Cijxx   = (self.QP_XX-self.QP_REF)/self.field_strength_FF
        Cijyy   = (self.QP_YY-self.QP_REF)/self.field_strength_FF
        Cijxxyy = (self.QP_XX-self.QP_YY)/self.field_strength_FF
        Cxxxx =  -Cijxxyy[0,0]/3.0
        Cxxyy =  -Cijxxyy[1,1]/3.0
        Cxxzz =  -Cijxxyy[2,2]/3.0
        Cyyyy =  +Cxxyy - Cijyy[1,1]
        Cyyzz =  +Cxxzz - Cijyy[2,2]
        Czzzz =  +Cxxzz + Cijxx[2,2]

        # Irreducible representation
        self.QQ_IJKL_IRREP = np.zeros(21)
        self.QQ_IJKL_IRREP[0]   = round(float(Cxxxx),5)
        self.QQ_IJKL_IRREP[1]   = round(float(Cijxx[0,1]),5)
        self.QQ_IJKL_IRREP[2]   = round(float(Cijxx[0,2]),5)
        self.QQ_IJKL_IRREP[3]   = round(float(Cxxyy),5)
        self.QQ_IJKL_IRREP[4]   = round(float(Cijxx[1,2]),5)
        self.QQ_IJKL_IRREP[5]   = round(float(Cxxzz),5)
        self.QQ_IJKL_IRREP[6]   = round(float(Cxyxy),5)
        self.QQ_IJKL_IRREP[7]   = round(float(Cxyxz),5)
        self.QQ_IJKL_IRREP[8]   = round(float(Cijyy[0,1]),5)
        self.QQ_IJKL_IRREP[9]   = round(float(Cxyyz),5)
        self.QQ_IJKL_IRREP[10]  = round(float(Cijzz[0,1]),5)
        self.QQ_IJKL_IRREP[11]  = round(float(Cxzxz),5)
        self.QQ_IJKL_IRREP[12]  = round(float(Cijyy[0,2]),5)
        self.QQ_IJKL_IRREP[13]  = round(float(Cxzyz),5)
        self.QQ_IJKL_IRREP[14]  = round(float(Cijzz[0,2]),5)
        self.QQ_IJKL_IRREP[15]  = round(float(Cyyyy),5)
        self.QQ_IJKL_IRREP[16]  = round(float(Cijyy[1,2]),5)
        self.QQ_IJKL_IRREP[17]  = round(float(Cyyzz),5)
        self.QQ_IJKL_IRREP[18]  = round(float(Cyzyz),5)
        self.QQ_IJKL_IRREP[19]  = round(float(Cijzz[1,2]),5)
        self.QQ_IJKL_IRREP[20]  = round(float(Czzzz),5)

 
        self.QQ_IJKL[0,0,0,0] = self.QQ_IJKL_IRREP[0]
        self.QQ_IJKL[[0,1,0,0],
                     [1,0,0,0],
                     [0,0,0,1],
                     [0,0,1,0]] = self.QQ_IJKL_IRREP[1]
        self.QQ_IJKL[[0,2,0,0],
                     [2,0,0,0],
                     [0,0,0,2],
                     [0,0,2,0]] = self.QQ_IJKL_IRREP[2]
        self.QQ_IJKL[[1,0],
                     [1,0],
                     [0,1],
                     [0,1]] = self.QQ_IJKL_IRREP[3]
        self.QQ_IJKL[[1,2,0,0],
                     [2,1,0,0],
                     [0,0,1,2],
                     [0,0,2,1]] = self.QQ_IJKL_IRREP[4]
        self.QQ_IJKL[[2,0],
                     [2,0],
                     [0,2],
                     [0,2]] = self.QQ_IJKL_IRREP[5]
        self.QQ_IJKL[[0,0,1,1],
                     [1,1,0,0],
                     [0,1,0,1],
                     [1,0,1,0]] = self.QQ_IJKL_IRREP[6]
        self.QQ_IJKL[[0,0,2,2,0,1,0,1],
                     [2,2,0,0,1,0,1,0],
                     [0,1,0,1,0,0,2,2],
                     [1,0,1,0,2,2,0,0]] = self.QQ_IJKL_IRREP[7]
        self.QQ_IJKL[[1,1,0,1],
                     [1,1,1,0],
                     [0,1,1,1],
                     [1,0,1,1]] = self.QQ_IJKL_IRREP[8]
        self.QQ_IJKL[[1,1,2,2,0,1,0,1],
                     [2,2,1,1,1,0,1,0],
                     [0,1,0,1,1,1,2,2],
                     [1,0,1,0,2,2,1,1]] = self.QQ_IJKL_IRREP[9]
        self.QQ_IJKL[[2,2,0,1],
                     [2,2,1,0],
                     [0,1,2,2],
                     [1,0,2,2]] = self.QQ_IJKL_IRREP[10]
        self.QQ_IJKL[[0,0,2,2],
                     [2,2,0,0],
                     [0,2,0,2],
                     [2,0,2,0]] = self.QQ_IJKL_IRREP[11]
        self.QQ_IJKL[[1,1,0,2],
                     [1,1,2,0],
                     [0,2,1,1],
                     [2,0,1,1]] = self.QQ_IJKL_IRREP[12]
        self.QQ_IJKL[[1,1,2,2,0,2,0,2],
                     [2,2,1,1,2,0,2,0],
                     [0,2,0,2,1,1,2,2],
                     [2,0,2,0,2,2,1,1]] = self.QQ_IJKL_IRREP[13]
        self.QQ_IJKL[[2,2,0,2],
                     [2,2,2,0],
                     [0,2,2,2],
                     [2,0,2,2]] = self.QQ_IJKL_IRREP[14]
        self.QQ_IJKL[1,1,1,1] = self.QQ_IJKL_IRREP[15]
        self.QQ_IJKL[[1,2,1,1],
                     [2,1,1,1],
                     [1,1,1,2],
                     [1,1,2,1]] = self.QQ_IJKL_IRREP[16]
        self.QQ_IJKL[[2,1],
                     [2,1],
                     [1,2],
                     [1,2]] = self.QQ_IJKL_IRREP[17]
        self.QQ_IJKL[[1,1,2,2],
                     [2,2,1,1],
                     [1,2,1,2],
                     [2,1,2,1]] = self.QQ_IJKL_IRREP[18]
        self.QQ_IJKL[[2,2,1,2],
                     [2,2,2,1],
                     [1,2,2,2],
                     [2,1,2,2]] = self.QQ_IJKL_IRREP[19]
        self.QQ_IJKL[2,2,2,2] = self.QQ_IJKL_IRREP[20]

        if self.irrep == True:
            np.save("H2O_mono_CIJKL_Trrep.npy",np.round(-self.QQ_IJKL_IRREP,4))
            return np.round(-self.QQ_IJKL_IRREP,4)
        else:
            np.save("H2O_mono_CIJKL.npy",np.round(-self.QQ_IJKL,4))
            return np.round(-self.QQ_IJKL,4)



"""
cpol_pyscf - A package for calculating molecular moments and polarizabilities using PySCF
"""

from . import momtensor
from . import poltensor
from . import qdist
from . import PySCFmerger

__version__ = "0.1.7"


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="cpol_pyscf",
    version="0.1.8",
    author="",
    author_email="mailanoopanair@gmail.com",
    description="A package for calculating molecular moments and polarizabilities using PySCF",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pypa/sampleproject",
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)

